#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class RangeBarCloseMarker : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int barsize = 2; 
			private Color markercolor = Color.Blue;
			private int thickness = 2;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Overlay				= true;
			CalculateOnBarClose = false;
        }
        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBar<10)
				return;
			
			
			double upper = Low[0]+(barsize)*TickSize;
			double lower = High[0]-(barsize)*TickSize;
			DrawLine("upper",false,-1,upper,1,upper,markercolor,DashStyle.Solid,thickness);
			DrawLine("lower",false,-1,lower,1,lower,markercolor,DashStyle.Solid,thickness);
			DrawTextFixed("uppertext","Close Up:     "+upper + "\n" + "Close Down: " + lower,TextPosition.BottomLeft);
			DrawText("uppertest",upper.ToString(),-10,upper,Color.Gray);
			DrawText("lowertest",lower.ToString(),-10,lower,Color.Gray);
			
        }

        #region Properties
        [Description("What size hybrid renko are you using?")]
        [GridCategory("Parameters")]
        public int BarSize
        {
            get { return barsize; }
            set { barsize = Math.Max(1, value); }
        }
		[Description("Thickness of the marker")]
        [GridCategory("Parameters")]
        public int MarkerThickness
        {
            get { return thickness; }
            set { thickness = Math.Max(1, value); }
        }
		[Description("Color of the marker")]
        [GridCategory("Parameters")]
        public Color MarkerColor
        {
            get { return markercolor; }
            set { markercolor = value; }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private RangeBarCloseMarker[] cacheRangeBarCloseMarker = null;

        private static RangeBarCloseMarker checkRangeBarCloseMarker = new RangeBarCloseMarker();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public RangeBarCloseMarker RangeBarCloseMarker(int barSize, Color markerColor, int markerThickness)
        {
            return RangeBarCloseMarker(Input, barSize, markerColor, markerThickness);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public RangeBarCloseMarker RangeBarCloseMarker(Data.IDataSeries input, int barSize, Color markerColor, int markerThickness)
        {
            if (cacheRangeBarCloseMarker != null)
                for (int idx = 0; idx < cacheRangeBarCloseMarker.Length; idx++)
                    if (cacheRangeBarCloseMarker[idx].BarSize == barSize && cacheRangeBarCloseMarker[idx].MarkerColor == markerColor && cacheRangeBarCloseMarker[idx].MarkerThickness == markerThickness && cacheRangeBarCloseMarker[idx].EqualsInput(input))
                        return cacheRangeBarCloseMarker[idx];

            lock (checkRangeBarCloseMarker)
            {
                checkRangeBarCloseMarker.BarSize = barSize;
                barSize = checkRangeBarCloseMarker.BarSize;
                checkRangeBarCloseMarker.MarkerColor = markerColor;
                markerColor = checkRangeBarCloseMarker.MarkerColor;
                checkRangeBarCloseMarker.MarkerThickness = markerThickness;
                markerThickness = checkRangeBarCloseMarker.MarkerThickness;

                if (cacheRangeBarCloseMarker != null)
                    for (int idx = 0; idx < cacheRangeBarCloseMarker.Length; idx++)
                        if (cacheRangeBarCloseMarker[idx].BarSize == barSize && cacheRangeBarCloseMarker[idx].MarkerColor == markerColor && cacheRangeBarCloseMarker[idx].MarkerThickness == markerThickness && cacheRangeBarCloseMarker[idx].EqualsInput(input))
                            return cacheRangeBarCloseMarker[idx];

                RangeBarCloseMarker indicator = new RangeBarCloseMarker();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.BarSize = barSize;
                indicator.MarkerColor = markerColor;
                indicator.MarkerThickness = markerThickness;
                Indicators.Add(indicator);
                indicator.SetUp();

                RangeBarCloseMarker[] tmp = new RangeBarCloseMarker[cacheRangeBarCloseMarker == null ? 1 : cacheRangeBarCloseMarker.Length + 1];
                if (cacheRangeBarCloseMarker != null)
                    cacheRangeBarCloseMarker.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheRangeBarCloseMarker = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.RangeBarCloseMarker RangeBarCloseMarker(int barSize, Color markerColor, int markerThickness)
        {
            return _indicator.RangeBarCloseMarker(Input, barSize, markerColor, markerThickness);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.RangeBarCloseMarker RangeBarCloseMarker(Data.IDataSeries input, int barSize, Color markerColor, int markerThickness)
        {
            return _indicator.RangeBarCloseMarker(input, barSize, markerColor, markerThickness);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.RangeBarCloseMarker RangeBarCloseMarker(int barSize, Color markerColor, int markerThickness)
        {
            return _indicator.RangeBarCloseMarker(Input, barSize, markerColor, markerThickness);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.RangeBarCloseMarker RangeBarCloseMarker(Data.IDataSeries input, int barSize, Color markerColor, int markerThickness)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.RangeBarCloseMarker(input, barSize, markerColor, markerThickness);
        }
    }
}
#endregion
